@@ -1,6 +1,6 @@
 /*
 
-  $Id: misc.c,v 1.126 2007/05/02 16:30:05 pkot Exp $
+  $Id$
 
   G N O K I I
 
@@ -93,6 +93,7 @@ static gn_phone_model models[] = {
 	{"1100",  "RH-18",	PM_OLD_DEFAULT },
 	{"1100",  "RH-38",	PM_OLD_DEFAULT },
 	{"1100b", "RH-36",	PM_OLD_DEFAULT },
+	{"1209",  "RH-105",	PM_OLD_DEFAULT },	/* phone supports a very limited command set */
 	{"1220",  "NKC-1",	PM_OLD_DEFAULT },
 	{"1260",  "NKW-1",	PM_OLD_DEFAULT },
 	{"1261",  "NKW-1C",	PM_OLD_DEFAULT },
@@ -126,6 +127,7 @@ static gn_phone_model models[] = {
 	{"2300",  "RM-4",	PM_OLD_DEFAULT },
 	{"2300b", "RM-5",	PM_OLD_DEFAULT },
 	{"2600",  "RH-59",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
+	{"2630",  "RM-298",	PM_DEFAULT },
 	{"2650",  "RH-53",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"3100",  "RH-19",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"3100b", "RH-50",	PM_DEFAULT },
@@ -133,6 +135,7 @@ static gn_phone_model models[] = {
 	{"3108",  "RH-6",	PM_OLD_DEFAULT },
 	{"3110",  "NHE-8",	PM_OLD_DEFAULT | PM_DATA },
 	{"3110",  "0310" ,	PM_OLD_DEFAULT | PM_DATA }, /* NHE-8 */
+	{"3110c", "RM-237",     PM_DEFAULT | PM_SMSFILE }, /* Nokia 3110 classic */
 	{"3120",  "RH-19",	PM_DEFAULT },
 	{"3120b", "RH-50",	PM_DEFAULT },
 	{"3200",  "RH-30",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
@@ -156,6 +159,7 @@ static gn_phone_model models[] = {
 	{"3390",  "NPB-1",	PM_OLD_DEFAULT },
 	{"3395",  "NPB-1B",	PM_OLD_DEFAULT },
 	{"3410",  "NHM-2",	PM_OLD_DEFAULT | PM_NETMONITOR },
+	{"3500c", "RM-272",	PM_DEFAULT },
 	{"3510",  "NHM-8",	PM_DEFAULT },
 	{"3510i", "RH-9",	PM_DEFAULT },
 	{"3520",  "RH-21",	PM_DEFAULT },
@@ -192,6 +196,7 @@ static gn_phone_model models[] = {
 	{"5185",  "NSD-1A",	PM_OLD_DEFAULT },
 	{"5190",  "NSB-1",	PM_OLD_DEFAULT | PM_NETMONITOR | PM_DATA | PM_AUTHENTICATION },
 	{"5210",  "NSM-5",	PM_DEFAULT },
+	{"5300",  "RM-146",	PM_DEFAULT },
 	{"5510",  "NPM-5",	PM_OLD_DEFAULT },
 	{"6010",  "NPM-10",	PM_OLD_DEFAULT },
 	{"6010",  "NPM-10X",	PM_OLD_DEFAULT },
@@ -199,7 +204,9 @@ static gn_phone_model models[] = {
 	{"6015i", "RH-55",	PM_DEFAULT | PM_NETMONITOR },
 	{"6020",  "RM-30",	PM_DEFAULT | PM_NETMONITOR },
 	{"6021",  "RM-94",	PM_DEFAULT | PM_NETMONITOR | PM_XGNOKIIBREAKAGE},
+	{"6030",  "RM-74",      PM_DEFAULT },
 	{"6050",  "NME-1",	PM_OLD_DEFAULT },
+	{"6070",  "RM-166",	PM_DEFAULT },
 	{"6080",  "NME-2",	PM_OLD_DEFAULT },
 	{"6081",  "NME-2A",	PM_OLD_DEFAULT },
 	{"6081",  "NME-2E",	PM_OLD_DEFAULT },
@@ -231,6 +238,7 @@ static gn_phone_model models[] = {
 	{"6233",  "RM123_145_-", PM_DEFAULT | PM_NETMONITOR },
 	{"6250",  "NHM-3",	PM_DEFAULT | PM_NETMONITOR },
 	{"6280",  "RH-78",	PM_DEFAULT | PM_NETMONITOR },
+	{"6300",  "RM-217",     PM_DEFAULT | PM_FULLPBK | PM_SMSFILE },
 	{"6310",  "NPE-4",	PM_DEFAULT },
 	{"6310i", "NPL-1",	PM_DEFAULT },
 	{"6340",  "NPM-2",	PM_OLD_DEFAULT },
@@ -254,6 +262,7 @@ static gn_phone_model models[] = {
 	{"6810",  "RM-2",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"6820",  "NHL-9",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"6820b", "RH-26",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
+	{"6822",  "RM-69",	PM_DEFAULT },
 	{"7110",  "NSE-5",	PM_DEFAULT | PM_NETMONITOR },
 	{"7160",  "NSW-5",	PM_OLD_DEFAULT },
 	{"7190",  "NSB-5",	PM_DEFAULT | PM_NETMONITOR },
@@ -264,6 +273,7 @@ static gn_phone_model models[] = {
 	{"7260",  "RM-17",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"7270",  "RM-8",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"7280",  "RM-14",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
+	{"7373",  "RM-209",	PM_DEFAULT },
 	{"7600",  "NMM-3",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"7650",  "NHL-2NA",	PM_DEFAULT },
 	{"8110",  "0423" ,	PM_OLD_DEFAULT | PM_DATA }, /* NHE-6BX */
@@ -301,6 +311,7 @@ static gn_phone_model models[] = {
 	{"9210i", "RAE-5N",	PM_OLD_DEFAULT },
 	{"9290",  "RAE-3N",	PM_OLD_DEFAULT },
 	{"N70",   "RM-84",      PM_DEFAULT },
+	{"N73",   "RM-133",	PM_DEFAULT },
 	{"RPM-1", "RPM-1",	PM_OLD_DEFAULT | PM_DATA },
 	{"Card Phone 1.0", "RPE-1",	PM_OLD_DEFAULT | PM_DATA },
 	{"Card Phone 2.0", "RPM-1",	PM_OLD_DEFAULT | PM_DATA },
@@ -310,6 +321,7 @@ static gn_phone_model models[] = {
 	{"N-Gage", "NEM-4",	PM_OLD_DEFAULT },
 	{"RinGo", "NHX-7",	PM_OLD_DEFAULT },
 	{"sx1",  "SX1",		PM_DEFAULT },
+	{"SIM/USIM", "pcsc",	0 },
 	{NULL,    NULL, 0 } /* keep last one as NULL */
 };
 
@@ -435,7 +447,7 @@ GNOKII_API char *gn_device_lock(const char* port)
 	int fd, len;
 
 	if (!port) {
-		fprintf(stderr, _("Cannot lock NULL device.\n"));
+		fprintf(stderr, _("Cannot lock NULL device. Set port config parameter correctly.\n"));
 		return NULL;
 	}
 
@@ -453,11 +465,12 @@ GNOKII_API char *gn_device_lock(const char* port)
 		fprintf(stderr, _("Out of memory error while locking device.\n"));
 		return NULL;
 	}
-	/* I think we don't need to use strncpy, as we should have enough
-	 * buffer due to strlen results
+	/*
+	 * I think we don't need to use strncpy, as we should have enough
+	 * buffer due to strlen results, but it's safer to do so...
 	 */
-	strcpy(lock_file, lock_path);
-	strcat(lock_file, aux);
+	strncpy(lock_file, lock_path, len);
+	strncat(lock_file, aux, len - strlen(lock_file));
 
 	/* Check for the stale lockfile.
 	 * The code taken from minicom by Miquel van Smoorenburg */
@@ -478,15 +491,15 @@ GNOKII_API char *gn_device_lock(const char* port)
 				sscanf(buf, "%d", &pid);
 			}
 			if (pid > 0 && kill((pid_t)pid, 0) < 0 && errno == ESRCH) {
-				fprintf(stderr, _("Lockfile %s is stale. Overriding it..\n"), lock_file);
+				fprintf(stderr, _("Lockfile %s is stale. Overriding it...\n"), lock_file);
 				sleep(1);
 				if (unlink(lock_file) == -1) {
-					fprintf(stderr, _("Overriding failed, please check the permissions.\n"));
+					fprintf(stderr, _("Overriding file %s failed, please check the permissions.\n"), lock_file);
 					fprintf(stderr, _("Cannot lock device.\n"));
 					goto failed;
 				}
 			} else {
-				fprintf(stderr, _("Device already locked.\n"));
+				fprintf(stderr, _("Device already locked with %s.\n"), lock_file);
 				goto failed;
 			}
 		}
@@ -510,15 +523,19 @@ GNOKII_API char *gn_device_lock(const char* port)
 		else if (errno == EACCES)
 			fprintf(stderr, _("Please check permission on lock directory.\n"));
 		else if (errno == ENOENT)
-			fprintf(stderr, _("Cannot create lockfile %s. Please check for existence of the path."), lock_file);
+			fprintf(stderr, _("Cannot create lockfile %s. Please check for existence of the path.\n"), lock_file);
+		goto failed;
+	}
+	snprintf(buffer, sizeof(buffer), "%10ld gnokii\n", (long)getpid());
+	if (write(fd, buffer, strlen(buffer)) < 0) {
+		fprintf(stderr, _("Failed to write to the lockfile %s.\n"), lock_file);
 		goto failed;
 	}
-	sprintf(buffer, "%10ld gnokii\n", (long)getpid());
-	/* Probably we should add some error checking in here */
-	write(fd, buffer, strlen(buffer));
 	close(fd);
 	return lock_file;
 failed:
+	if (fd > -1)
+		close(fd);
 	free(lock_file);
 	return NULL;
 #else
@@ -527,18 +544,20 @@ failed:
 }
 
 /* Removes lock and frees memory */
-GNOKII_API bool gn_device_unlock(char *lock_file)
+GNOKII_API int gn_device_unlock(char *lock_file)
 {
 #ifndef WIN32
 	int err;
 
-	if (!lock_file) {
-		fprintf(stderr, _("Cannot unlock device.\n"));
-		return false;
+	if (lock_file) {
+		err = unlink(lock_file);
+		free(lock_file);
+		if (err) {
+			fprintf(stderr, _("Cannot unlock device: %s\n"), strerror(errno));
+			return false;
+		}
 	}
-	err = unlink(lock_file);
-	free(lock_file);
-	return (err + 1);
+	return true;
 #else
 	return true;
 #endif /* WIN32 */
@@ -557,7 +576,12 @@ char **gnokii_strsplit(const char *string, const char *delimiter, int tokens)
 	if (!string || !delimiter || !tokens)
 		return NULL;
 
-	strings = calloc(tokens + 1, sizeof(char *));
+	/*
+	 * Last two elements are:
+	 *  - leftover from the input line
+	 *  - NULL (required by gnokii_strfreev())
+	 */
+	strings = calloc(tokens + 2, sizeof(char *));
 
 	while ((tmp = strstr(left, delimiter)) != NULL && (count < tokens)) {
 		str = malloc((tmp - left) + 1);
@@ -569,6 +593,11 @@ char **gnokii_strsplit(const char *string, const char *delimiter, int tokens)
 	}
 
 	strings[count] = strdup(left);
+	/*
+	 * Make NULL termination explicit even if it is done via calloc().
+	 * gnokii_strfreev() requires it to be NULL-terminated.
+	 */
+	strings[count + 1] = NULL;
 
 	for (count = 0; count < tokens; count++) {
 		dprintf("strings[%d] = %s\n", count, strings[count]);
