@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii-security.c,v 1.7 2007/02/03 22:28:07 pkot Exp $
+  $Id$
 
   G N O K I I
 
@@ -50,6 +50,8 @@
 #include "gnokii-app.h"
 #include "gnokii.h"
 
+#define PRINT_ERROR(error)	fprintf(stderr, "%s\n", gn_error_print(error))
+
 void security_usage(FILE *f)
 {
 	fprintf(f, _(
@@ -59,7 +61,7 @@ void security_usage(FILE *f)
 		));
 #ifdef SECURITY
 	fprintf(f, _(
-		     "          --entersecuritycode PIN|PIN2|PUK|PUK2\n"
+		     "          --entersecuritycode PIN|PIN2|PUK|PUK2|SEC (CMD...)\n"
 		     "          --getsecuritycodestatus\n"
 		     "          --getsecuritycode\n"
 		     "          --changesecuritycode PIN|PIN2|PUK|PUK2\n"
@@ -67,7 +69,7 @@ void security_usage(FILE *f)
 #endif
 }
 
-int identify(struct gn_statemachine *state)
+gn_error identify(struct gn_statemachine *state)
 {
 	fprintf(stdout, _("IMEI         : %s\n"), gn_lib_get_phone_imei(state));
 	fprintf(stdout, _("Manufacturer : %s\n"), gn_lib_get_phone_manufacturer(state));
@@ -78,7 +80,7 @@ int identify(struct gn_statemachine *state)
 	return gn_lib_lasterror(state);
 }
 
-int getlocksinfo(gn_data *data, struct gn_statemachine *state)
+gn_error getlocksinfo(gn_data *data, struct gn_statemachine *state)
 {
 	gn_locks_info locks_info[4];
 	gn_error error;
@@ -89,6 +91,7 @@ int getlocksinfo(gn_data *data, struct gn_statemachine *state)
 	data->locks_info = locks_info;
 
 	if ((error = gn_sm_functions(GN_OP_GetLocksInfo, data, state)) != GN_ERR_NONE) {
+		PRINT_ERROR(error);
 		return error;
 	}
 
@@ -100,12 +103,12 @@ int getlocksinfo(gn_data *data, struct gn_statemachine *state)
 			locks_info[i].closed ? "CLOSED" : "open",
 			locks_info[i].counter);
 	}
-	return 0;
+	return GN_ERR_NONE;
 }
 
 #ifdef SECURITY
 
-int getsecuritycode(gn_data *data, struct gn_statemachine *state)
+gn_error getsecuritycode(gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error;
 	gn_security_code sc;
@@ -115,25 +118,50 @@ int getsecuritycode(gn_data *data, struct gn_statemachine *state)
 	data->security_code = &sc;
 	fprintf(stderr, _("Getting security code... \n"));
 	error = gn_sm_functions(GN_OP_GetSecurityCode, data, state);
-	fprintf(stdout, _("Security code is: %s\n"), sc.code);
+	switch (error) {
+	case GN_ERR_NONE:
+		fprintf(stdout, _("Security code is: %s\n"), sc.code);
+		break;
+	default:
+		PRINT_ERROR(error);
+		break;
+	}
 	return error;
 }
 
 static int get_password(const char *prompt, char *pass, int length)
 {
 #ifdef WIN32
+	int count = 0;
+
 	fprintf(stdout, "%s", prompt);
 	fgets(pass, length, stdin);
+
+	/* strip the trailing newline to be compatible with getpass() */
+	while (count < length && pass[count]) {
+		if (pass[count] == '\r' || pass[count] == '\n') {
+			pass[count] = '\0';
+			break;
+		}
+		count++;
+	}
 #else
 	/* FIXME: manual says: Do not use getpass */
 	char *s = NULL;
-	int err, s_len, fd = fileno(stdin);
+	int fd = fileno(stdin);
+	ssize_t count;
+	size_t s_len;
 
 	if (isatty(fd)) {
 		strncpy(pass, getpass(prompt), length - 1);
 	} else {
-		err = getline(&s, &s_len, stdin);
-		if (err > 0 && s) {
+		count = getline(&s, &s_len, stdin);
+		if (count > 0 && s) {
+			/* strip the trailing newline to be compatible with getpass() */
+			count--;
+			if (s[count] == '\n') {
+				s[count] = '\0';
+			}
 			strncpy(pass, s, length - 1);
 			free(s);
 		}
@@ -143,15 +171,15 @@ static int get_password(const char *prompt, char *pass, int length)
 	return 0;
 }
 
-void entersecuritycode_usage(FILE *f, int exitval)
+int entersecuritycode_usage(FILE *f, int exitval)
 {
-	fprintf(f, _(" usage: --entersecuritycode PIN|PIN2|PUK|PUK2\n"));
-	exit(exitval);
+	fprintf(f, _(" usage: --entersecuritycode PIN|PIN2|PUK|PUK2|SEC\n"));
+	return exitval;
 }
 
 /* In this mode we get the code from the keyboard and send it to the mobile
    phone. */
-int entersecuritycode(char *type, gn_data *data, struct gn_statemachine *state)
+gn_error entersecuritycode(char *type, gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error;
 	gn_security_code security_code;
@@ -164,12 +192,10 @@ int entersecuritycode(char *type, gn_data *data, struct gn_statemachine *state)
 		security_code.type = GN_SCT_Pin2;
 	else if (!strcmp(type, "PUK2"))
 		security_code.type = GN_SCT_Puk2;
-	/* FIXME: Entering of security_code does not work :-(
-	else if (!strcmp(type, "security_code"))
-		security_code.type = GN_SCT_security_code;
-	*/
+	else if (!strcmp(type, "SEC"))
+		security_code.type = GN_SCT_SecurityCode;
 	else
-		entersecuritycode_usage(stderr, -1);
+		return entersecuritycode_usage(stderr, -1);
 
 	memset(&security_code.code, 0, sizeof(security_code.code));
 	get_password(_("Enter your code: "), security_code.code, sizeof(security_code.code));
@@ -190,7 +216,7 @@ int entersecuritycode(char *type, gn_data *data, struct gn_statemachine *state)
 	return error;
 }
 
-int getsecuritycodestatus(gn_data *data, struct gn_statemachine *state)
+gn_error getsecuritycodestatus(gn_data *data, struct gn_statemachine *state)
 {
 	gn_security_code security_code;
 	gn_error err;
@@ -231,13 +257,13 @@ int getsecuritycodestatus(gn_data *data, struct gn_statemachine *state)
 	return err;
 }
 
-void changesecuritycode_usage(FILE *f, int exitval)
+int changesecuritycode_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --changesecuritycode PIN|PIN2|PUK|PUK2\n"));
-	exit(exitval);
+	return exitval;
 }
 
-int changesecuritycode(char *type, gn_data *data, struct gn_statemachine *state)
+gn_error changesecuritycode(char *type, gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error;
 	gn_security_code security_code;
@@ -258,14 +284,14 @@ int changesecuritycode(char *type, gn_data *data, struct gn_statemachine *state)
 		security_code.type = GN_SCT_security_code;
 	*/
 	else
-		changesecuritycode_usage(stderr, -1);
+		return changesecuritycode_usage(stderr, -1);
 
 	get_password(_("Enter your code: "), security_code.code, sizeof(security_code.code));
 	get_password(_("Enter new code: "), security_code.new_code, sizeof(security_code.new_code));
 	get_password(_("Retype new code: "), newcode2, sizeof(newcode2));
 	if (strcmp(security_code.new_code, newcode2)) {
-		fprintf(stdout, _("Error: new code differ\n"));
-		return -1;
+		fprintf(stderr, _("Error: new code differs\n"));
+		return GN_ERR_FAILED;
 	}
 
 	gn_data_clear(data);
@@ -277,7 +303,7 @@ int changesecuritycode(char *type, gn_data *data, struct gn_statemachine *state)
 		fprintf(stderr, _("Code changed.\n"));
 		break;
 	default:
-		fprintf(stderr, _("Error: %s\n"), gn_error_print(error));
+		PRINT_ERROR(error);
 		break;
 	}
 
