@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii.c,v 1.483 2008/05/08 13:37:05 dforsi Exp $
+  $Id$
 
   G N O K I I
 
@@ -84,11 +84,15 @@
 
 #endif
 
-
 #ifdef ENABLE_NLS
 #  include <locale.h>
 #endif
 
+#ifdef HAVE_READLINE
+#  include <readline/readline.h>
+#  include <readline/history.h>
+#endif
+
 #include "gnokii-app.h"
 #include "gnokii.h"
 #include <sys/stat.h>
@@ -188,7 +192,10 @@ typedef enum {
 	OPT_DELETEFILE,
 	OPT_DELETEFILEBYID,
 	OPT_CONFIGFILE,
-	OPT_CONFIGMODEL
+	OPT_CONFIGMODEL,
+	OPT_SHELL,
+	OPT_GETMMS,			/* 340 */
+	OPT_DELETEMMS
 } opt_index;
 
 static FILE *logfile = NULL;
@@ -207,8 +214,9 @@ static void version(void)
 	fprintf(stderr, _("Copyright (C) Hugh Blemings <hugh@blemings.org>, 1999, 2000\n"
 			  "Copyright (C) Pavel Janik ml. <Pavel.Janik@suse.cz>, 1999, 2000\n"
 			  "Copyright (C) Pavel Machek <pavel@ucw.cz>, 2001\n"
-			  "Copyright (C) Pawel Kot <pkot@linuxnews.pl>, 2001-2006\n"
+			  "Copyright (C) Pawel Kot <gnokii@gmail.com>, 2001-2009\n"
 			  "Copyright (C) BORBELY Zoltan <bozo@andrews.hu>, 2002\n"
+			  "Copyright (C) Daniele Forsi <daniele@forsi.it>, 2004-2009\n"
 			  "gnokii is free software, covered by the GNU General Public License, and you are\n"
 			  "welcome to change it and/or distribute copies of it under certain conditions.\n"
 			  "There is absolutely no warranty for gnokii.  See GPL for details.\n"
@@ -228,9 +236,11 @@ static int usage(FILE *f, int retval)
 		     "Use just one option at a time.\n"
 		     "General options:\n"
 		     "          --help\n"
-		     "          --version\n"));
+		     "          --version\n"
+		     "          --shell\n"));
 	monitor_usage(f);
 	sms_usage(f);
+	mms_usage(f);
 	phonebook_usage(f);
 	calendar_usage(f);
 	todo_usage(f);
@@ -243,7 +253,7 @@ static int usage(FILE *f, int retval)
 	security_usage(f);
 	file_usage(f);
 	other_usage(f);
-	exit(retval);
+	return retval;
 }
 
 static void gnokii_error_logger(const char *fmt, va_list ap)
@@ -299,7 +309,7 @@ static void busterminate(void)
 	gn_lib_library_free();
 }
 
-static void businit(void)
+static int businit(void)
 {
 	gn_error err;
 	if ((err = gn_lib_phoneprofile_load_from_file(configfile, configmodel, &state)) != GN_ERR_NONE) {
@@ -308,7 +318,7 @@ static void businit(void)
 			fprintf(stderr, _("File: %s\n"), configfile);
 		if (configmodel)
 			fprintf(stderr, _("Phone section: [phone_%s]\n"), configmodel);
-		exit(2);
+		return 2;
 	}
 
 	/* register cleanup function */
@@ -321,9 +331,10 @@ static void businit(void)
 
 	if ((err = gn_lib_phone_open(state)) != GN_ERR_NONE) {
 		fprintf(stderr, "%s\n", gn_error_print(err));
-		exit(2);
+		return 2;
 	}
 	data = &state->sm_data;
+	return 0;
 }
 
 /* This function checks that the argument count for a given options is within
@@ -373,7 +384,7 @@ static int foogle(int argc, char *argv[])
 {
 	/* Fill in what you would like to test here... */
 	/* remember to call businit(); if you need to communicate with your phone */
-	return 0;
+	return GN_ERR_NONE;
 }
 #endif
 
@@ -632,6 +643,15 @@ static int parse_options(int argc, char *argv[])
 		/* Delete a file by id */
 		{ "deletefilebyid",     required_argument, NULL, OPT_DELETEFILEBYID },
 
+		/* shell like interface */
+		{ "shell",              no_argument, NULL, OPT_SHELL },
+
+		/* Get MMS message mode */
+		{ "getmms",             required_argument, NULL, OPT_GETMMS },
+
+		/* Delete MMS message mode */
+		{ "deletemms",          required_argument, NULL, OPT_DELETEMMS },
+
 		{ 0, 0, 0, 0 },
 	};
 
@@ -661,10 +681,10 @@ static int parse_options(int argc, char *argv[])
 		{ OPT_SETSPEEDDIAL,      3, 3, 0 },
 		{ OPT_CREATESMSFOLDER,   1, 1, 0 },
 		{ OPT_DELETESMSFOLDER,   1, 1, 0 },
-		{ OPT_GETSMS,            2, 5, 0 },
+		{ OPT_GETSMS,            2, 6, 0 },
 		{ OPT_DELETESMS,         2, 3, 0 },
 		{ OPT_SENDSMS,           1, 10, 0 },
-		{ OPT_SAVESMS,           0, 10, 0 },
+		{ OPT_SAVESMS,           0, 12, 0 },
 		{ OPT_SENDLOGO,          3, 4, GAL_XOR },
 		{ OPT_SENDRINGTONE,      2, 2, 0 },
 		{ OPT_GETSMSC,           0, 3, 0 },
@@ -699,6 +719,10 @@ static int parse_options(int argc, char *argv[])
 		{ OPT_PUTFILE,           2, 2, 0 },
 		{ OPT_DELETEFILE,        1, 1, 0 },
 		{ OPT_DELETEFILEBYID,    1, 1, 0 },
+		{ OPT_SHELL,             0, 0, 0 },
+		{ OPT_GETMMS,            2, 6, 0 },
+		{ OPT_DELETEMMS,         2, 3, 0 },
+		{ OPT_FOOGLE,            0, 0, 0 },
 		{ 0, 0, 0, 0 },
 	};
 
@@ -711,18 +735,22 @@ static int parse_options(int argc, char *argv[])
 	switch (c) {
 	/* No argument given - we should display usage. */
 	case -1:
-		usage(stderr, -1);
+		return usage(stderr, -1);
 	/* First, error conditions */
 	case '?':
 	case ':':
-		fprintf(stderr, _("Use '%s --help' for usage information.\n"), argv[0]);
-		exit(1);
+		/* --shell command does not set argv[0] */
+		if (argv[0])
+			fprintf(stderr, _("Use '%s --help' for usage information.\n"), argv[0]);
+		else
+			fprintf(stderr, _("Use '--help' for usage information.\n"));
+		return 1;
 	/* Then, options with no arguments */
 	case OPT_HELP:
-		usage(stdout, -1);
+		return usage(stdout, 0);
 	case OPT_VERSION:
 		version();
-		exit(0);
+		return 0;
 	/* That's a bit ugly... */
 	case 'c':
 		c = OPT_CONFIGFILE;
@@ -740,19 +768,19 @@ static int parse_options(int argc, char *argv[])
 	   not work as expected; instead args --cmd2 args is passed as a
 	   parameter. */
 	if (checkargs(c, gals, argc, long_options[opt_index].has_arg)) {
-		usage(stderr, -1);
+		return usage(stderr, -1);
 	}
 
 	/* Other options that do not need initialization */
 	switch (c) {
 	case OPT_CONFIGFILE:
 		if (configfile)
-			usage(stderr, -1);
+			return usage(stderr, -1);
 		configfile = optarg;
 		return parse_options(argc, argv);
 	case OPT_CONFIGMODEL:
 		if (configmodel)
-			usage(stderr, -1);
+			return usage(stderr, -1);
 		configmodel = optarg;
 		return parse_options(argc, argv);
 	case OPT_VIEWLOGO:
@@ -765,8 +793,8 @@ static int parse_options(int argc, char *argv[])
 	}
 
 	/* Initialise the code for the GSM interface. */
-	if (c != OPT_FOOGLE && state == NULL)
-		businit();
+	if (c != OPT_FOOGLE && state == NULL && businit())
+		return -1;
 
 	switch (c) {
 	/* Monitoring options */
@@ -1019,11 +1047,21 @@ static int parse_options(int argc, char *argv[])
 	case OPT_GETNETWORKINFO:
 		rc = getnetworkinfo(data, state);
 		break;
+	case OPT_SHELL:
+		rc = shell(data, state);
+		break;
 #ifndef WIN32
 	case OPT_FOOGLE:
 		rc = foogle(argc, argv);
 		break;
 #endif
+	/* MMS options */
+	case OPT_GETMMS:
+		rc = getmms(argc, argv, data, state);
+		break;
+	case OPT_DELETEMMS:
+		rc = deletemms(argc, argv, data, state);
+		break;
 	default:
 		rc = GN_ERR_FAILED;
 		fprintf(stderr, _("Unknown option: %d\n"), c);
@@ -1032,6 +1070,55 @@ static int parse_options(int argc, char *argv[])
 	return rc;
 }
 
+#define ARGV_CHUNK 10
+
+int shell(gn_data *data, struct gn_statemachine *state)
+{
+#ifdef HAVE_READLINE
+	char *input = NULL, *tmp, *old;
+	int len, i, argc = 1;
+	char **argv = NULL;
+	int size = ARGV_CHUNK;
+
+	argv = calloc(size, sizeof(char *));
+	while (1) {
+		argc = 1;
+		optind = opterr = optopt = 0;
+		optarg = NULL;
+		input = readline("gnokii> ");
+		old = input;
+		if (!input)
+			break;
+		do {
+			if (argc >= size) {
+				size += ARGV_CHUNK;
+				argv = realloc(argv, size * sizeof(char *));
+			}
+			while (*input == ' ')
+				input++;
+			tmp = strstr(input, " ");
+			if (tmp)
+				len = tmp - input;
+			else
+				len = strlen(input);
+			if (len > 0)
+				argv[argc++] = strdup(input);
+			input = tmp;
+		} while (input);
+		argv[argc] = NULL;
+		parse_options(argc, argv);
+		for (i = 1; i < argc; i++)
+			free(argv[i]);
+		free(old);
+	}
+	free(argv);
+	return 0;
+#else
+	fprintf(stderr, "gnokii needs to be compiled with getline support to enable this option.\n");
+	return -1;
+#endif
+}
+
 /* Main function - handles command line arguments, passes them to separate
    functions accordingly. */
 int main(int argc, char *argv[])
