@@ -1,6 +1,6 @@
 /*
 
-  $Id: config.h,v 1.32 2006/08/27 22:28:53 pkot Exp $
+  $Id$
 
   G N O K I I
 
@@ -37,10 +37,9 @@
 #else
 #	error This config.h is only for MSVC6 compiler !!!
 #endif
-
 	
 #undef VERSION
-#define VERSION "0.6.14"
+#define VERSION "0.6.28cvs"
 
 /* No bluetooth and no IRDA */
 #undef HAVE_BLUETOOTH
@@ -83,7 +82,7 @@
 #undef HAVE_TERMIOS_CSPEED
 
 /* Define both if you have ISO C99 compliant snprintf */
-#define HAVE_SNPRINTF
+#undef HAVE_SNPRINTF
 #undef HAVE_C99_SNPRINTF
 
 /* Define both if you have ISO C99 compliant vsnprintf */
@@ -113,6 +112,9 @@
 /* Define if you want NLS */
 #undef ENABLE_NLS
 
+/* Define if you have <langinfo.h> and nl_langinfo(CODESET). */
+#undef HAVE_LANGINFO_CODESET
+
 /* Define if you want to use Unix98 PTYs */
 #undef USE_UNIX98PTYS
 
@@ -124,5 +126,9 @@
 #pragma warning(disable : 4761) // integral size mismatch in argument; conversion supplied
 #pragma warning(disable : 4018) // signed/unsigned mismatch
 #pragma warning(disable : 4305) // truncation from 'const int ' to 'char '
+#pragma warning(disable : 4996) // 'strnicmp' was declared deprecated
+
+/* Suppress CRT warnings */
+#define _CRT_SECURE_NO_DEPRECATE
 
 #endif // _config_h
