@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_data.c,v 1.15 2006/08/15 10:57:20 dforsi Exp $
+  $Id$
 
   X G N O K I I
 
@@ -22,13 +22,15 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999 Pavel Janik ml., Hugh Blemings
   & 1999-2005 Jan Derfinak.
   Copyright (C) 2002-2004 Pawel Kot
   Copyright (C) 2002      BORBELY Zoltan
  
 */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <gtk/gtk.h>
 #include "misc.h"
@@ -42,13 +44,6 @@ bool GTerminateThread = false;
 bool enabled = false;
 static GtkWidget *label = NULL;
 
-static inline void Help1(GtkWidget * w, gpointer data)
-{
-	gchar *indx = g_strdup_printf("/help/%s/windows/data/index.html", xgnokiiConfig.help_locale);
-	Help(w, indx);
-	g_free(indx);
-}
-
 static void UpdateStatus(void)
 {
 	gchar *buf;
@@ -65,7 +60,7 @@ static void UpdateStatus(void)
 }
 
 
-inline void GUI_ShowData(void)
+void GUI_ShowData(void)
 {
 	if (!phoneMonitor.supported & PM_DATA)
 		return;
@@ -80,8 +75,7 @@ inline void GUI_ShowData(void)
 	gtk_window_present(GTK_WINDOW(GUI_DataWindow));
 }
 
-
-inline void GUI_HideData(void)
+static void GUI_HideData(void)
 {
 	gtk_widget_hide(GUI_DataWindow);
 }
